.. _spkg_sphinxcontrib_serializinghtml:

sphinxcontrib_serializinghtml: Sphinx extension which outputs serialized HTML files
=============================================================================================

Description
-----------

Sphinx extension which outputs serialized HTML files

License
-------

BSD

Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    1.1.10

version_requirements.txt::

    sphinxcontrib_serializinghtml >=1.1.5


Equivalent System Packages
--------------------------

.. tab:: Arch Linux

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-sphinxcontrib-serializinghtml 


.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install sphinxcontrib-serializinghtml 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo yum install python3-sphinxcontrib-serializinghtml 


.. tab:: FreeBSD

   .. CODE-BLOCK:: bash

       $ sudo pkg install textproc/py-sphinxcontrib-serializinghtml 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/sphinxcontrib-serializinghtml 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install py-sphinxcontrib-serializinghtml 


.. tab:: openSUSE

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3\$\{PYTHON_MINOR\}-sphinxcontrib-serializinghtml 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-sphinxcontrib-serializinghtml 



See https://repology.org/project/python:sphinxcontrib-serializinghtml/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure``
will check if the system package can be used.

